@@ -1,39 +1,40 @@
 #' @title Permutation-based All-Resolutions Inference for brain imaging.
-#' @description The main function for brain imaging All-Resolutions Inference (ARI) method based on critical vectors constructed 
-#' using the p-values permutation distribution. The function computes simultaneous lower bounds for the number of true discoveries 
-#' for each set of hypotheses specified in \code{ix} controlling family-wise error rate.
+#' @description The main function for All-Resolutions Inference (ARI) method based on the critical vector constructed 
+#' using the \eqn{p}-values permutation distribution. The function computes simultaneous lower bounds for the number of true discoveries 
+#' for each set of hypotheses specified in \code{ix} controlling family-wise error rate at level \code{alpha}.
 #' @usage pARIbrain(copes, thr=NULL, mask=NULL, alpha=.05, clusters = NULL, 
 #' alternative = "two.sided", summary_stat=c("max", "center-of-mass"),
 #' silent=FALSE, family = "simes", delta = 0, B = 1000, rand = FALSE, 
 #' iterative = FALSE, approx = TRUE, ncomb = 100, step.down = FALSE, max.step = 10, ...)
-#' @param copes list of NIfTI file. The list of copes, i.e., constrasts maps, one for each subject used to compute the statistical tests.
-#' @param thr numeric value. Threshold used to construct the cluster map. Default @NULL.
+#' @param copes List of NIfTI file. The list of copes, i.e., contrasts maps, one for each subject used to compute the statistical tests.
+#' @param thr Numeric value. Threshold used to construct the cluster map. Default to \code{NULL}.
 #' @param mask NIfTI file or character string. 3D array of logical values (i.e. \code{TRUE/FALSE} in/out of the brain). 
-#' Alternatively it may be a (character) NIfTI file name. If \code{mask=NULL}, it is assumed that non of the voxels have to be excluded.
-#' @param alpha numeric value in `[0,1]`. It expresses the alpha level to control the family-wise error rate. Default 0.05.
+#' Alternatively it may be a (character) NIfTI file name. If \code{mask=NULL}, it is assumed that none of the voxels have to be excluded.
+#' @param alpha Numeric value in `[0,1]`. \eqn{\alpha} level to control the family-wise error rate. Default to 0.05.
 #' @param clusters NIfTI file or character string. 3D array of cluster ids (0 when voxel does not belong to any cluster) or a (character) NIfTI file name. 
-#' If \code{cluster=NULL} the cluster map is computed by the \code{\link{cluster_threshold}} function with threshold equals \code{thr}.
-#' @param alternative character string. It refers to the alternative hypothesis, must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"lower"}.
-#' @param summary_stat character string. Choose among \code{=c("max", "center-of-mass")}. 
-#' @param silent Boolean value. Default @FALSE. If @TRUE the function prints the results.
-#' @param family string character. Choose a family of confidence envelopes to compute the critical vector 
-#' from \code{"simes"}, \code{"aorc"}, \code{"beta"} and \code{"higher.criticism"}.#' @param alpha alpha level.
-#' @param delta numeric value. It expresses the delta value, please see the references. Default to 0. 
-#' @param B numeric value. Number of permutations, default to 1000. 
-#' @param rand Boolean value. Default @FALSE. If \code{rand = TRUE}, the p-values are computed by \code{\link{rowRanks}}.
-#' @param iterative Boolean value. If \code{iterative = TRUE}, the iterative method for improvement of confidence envelopes is applied. Default @FALSE.
-#' @param approx Boolean value. Default @TRUE. If you are treating high dimensional data, we suggest to put \code{approx = TRUE} to speed up the computation time.
-#' @param ncomb Numeric value. If \code{approx = TRUE}, you must decide how many random subcollections (level of approximation) considered.
-#' @param step.down Boolean value. Default @FALSE If you want to compute the lambda calibration parameter using the step-down approach put @TRUE.
+#' If \code{cluster=NULL} the cluster map is computed by the \code{cluster_threshold} function with threshold equals \code{thr}.
+#' @param alternative Character string. It refers to the alternative hypothesis, must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"lower"}.
+#' @param summary_stat Character string. Choose among \code{=c("max", "center-of-mass")}. 
+#' @param silent Boolean value. Default to \code{FALSE}. If \code{TRUE} the function prints the results.
+#' @param family String character. Name of the family confidence envelope to compute the critical vector 
+#' from \code{"simes"}, \code{"aorc"}, \code{"beta"}, \code{"higher.criticism"}, and \code{"power"}.
+#' Default to "simes".
+#' @param delta Numeric value. \eqn{\delta} value. Please see the reference below. Default to 0. 
+#' @param B Numeric value. Number of permutations, default to 1000. 
+#' @param rand Boolean value. Default to \code{FALSE}. If \code{rand = TRUE}, the \eqn{p}-values are computed by \code{rowRanks}. Please see \code{\link{signTest}}
+#' @param iterative Boolean value. If \code{iterative = TRUE}, the iterative method is applied (computationally demanding). Default to \code{FALSE}. Please see the reference below.
+#' @param approx Boolean value. Default to \code{TRUE}. If you are analyzing high dimensional data, we suggest to put \code{approx = TRUE} to speed up the computation time. Please see the reference below.
+#' @param ncomb Numeric value. If \code{approx = TRUE}, you must decide how many random sub collections (level of approximation) considered. Default to 100.
+#' @param step.down Boolean value. Default to \code{FALSE} If you want to compute the lambda calibration parameter using the step-down approach put \code{TRUE}. Please see the reference below.
 #' @param max.step Numeric value. Default to 10. Maximum number of steps for the step down approach, so useful when \code{step.down = TRUE}.
 #' @param ... further arguments. See \code{signTest}.
 #' @author Angela Andreella
-#' @return A list with elements
-#' - out: data.frame containing the size, the number of false null hypotheses, 
-#' the number of true null hypotheses, the lower bound for the true discovery proportion, and other
-#' statistics for each cluster.
-#' - clusters: matrix describing the clusters analyzed.
-#' 
+#' @return A list with elements:
+#' \describe{
+#'  \item{out}{Data.frame containing the size, the number of false null hypotheses, the number of true null hypotheses, the lower bound for the true discovery proportion, and other statistics for each cluster.}
+#'  \item{clusters}{Matrix describing the clusters analyzed.}
+#' }
+#' @seealso \code{\link{signTest}}, \code{\link{lambdaOpt}},  \code{\link{criticalVector}}
 #' @export
 #' @importFrom RNifti readNifti
 #' @importFrom plyr laply
@@ -48,7 +49,7 @@
 #' 
 #' For permutation-based All-Resolutions Inference see:
 #' 
-#' Andreella, Angela, et al. "Permutation-based true discovery proportions for fMRI cluster analysis." arXiv preprint arXiv:2012.00368 (2020).
+#' Andreella, A., Hemerik, J., Finos, L., Weeda, W., & Goeman, J. (2023). Permutation-based true discovery proportions for functional magnetic resonance imaging cluster analysis. Statistics in Medicine, 42(14), 2311-2340.
 #' 
 #' @examples
 #' \dontrun{
@@ -68,30 +69,48 @@
 pARIbrain <- function(copes, thr=NULL, mask=NULL, alpha=.05, clusters = NULL, 
                       alternative = "two.sided", summary_stat=c("max", "center-of-mass"),
                       silent=FALSE, family = "simes", delta = 0, B = 1000, rand = FALSE, 
-                      iterative = FALSE, approx = TRUE, ncomb = 100, step.down = FALSE, max.step = 10, ...){
+                      iterative = FALSE, approx = TRUE, ncomb = 100, step.down = FALSE, 
+                      max.step = 10, ...){
   
   "%ni%" <- Negate("%in%")
+  
   #check alpha
   val_alpha = sapply(c(1:B), function(x) (B-x)/B)
   if(!(alpha %in% val_alpha)){stop('please insert valid values for alpha and B')}
   
-  family_set <- c("simes", "aorc", "beta", "higher.criticism")
+  #check copes
+  if(!is.list(copes)){stop("Please insert the list of copes as list class object")}
+  n <- length(copes)
+  if(n <= 1){stop("Please insert the list of copes as list class object")}
+  
+  #img_dims <- c(91,  109 , 91)
+  img_dims <- dim(copes[[1]])
+  
+  #check mask
+  if(!is.null(mask)){
+    if(!is.character(mask) && !is.array(mask)){stop("mask must be an array or a path")}
+    if(is.character(mask)){mask =readNifti(mask)}
+    if(!all(dim(mask) == img_dims)){stop("incompatible dimensions of mask and copes")}
+  }else{
+    mask <- array(1, img_dims)
+  }
+  
+  family_set <- c("simes", "aorc", "beta", "higher.criticism", "power")
   alternative_set <- c("two.sided", "greater", "lower")
   family <- match.arg(tolower(family), family_set)
   alternative <- match.arg(tolower(alternative), alternative_set)
   
-  if(is.character(mask)){mask = readNifti(mask)}
-  if(!is.list(copes)){stop("Please insert the list of copes as list class object")}
 
-  img_dims <- c(91,  109 , 91)
-  img <- array(NA, c(img_dims, length(copes)))
+  #create matrix of scores
+  img <- array(NA, c(img_dims, n))
   
-  for (sid in 1:length(copes)) {  
+  for (sid in seq(n)) {  
+    if(!(all(dim(copes[[sid]]) == img_dims))){stop("incompatible copes dimensions")}
     img[,,,sid] <- copes[[sid]]
     
   }
   
-  scores <- matrix(img,nrow=(91*109*91),ncol=length(copes))
+  scores <- matrix(img,nrow=(img_dims[1]*img_dims[2]*img_dims[3]),ncol=length(copes))
   scores[!mask,] = NA
   resO <-oneSamplePar(X=scores,alternative = alternative)
   
@@ -100,7 +119,7 @@ pARIbrain <- function(copes, thr=NULL, mask=NULL, alpha=.05, clusters = NULL,
   
   pvalues <- cbind(res$pv,res$pv_H0)
 #  pvalues = t(pvalues)
-  Statmap = array(data = resO$Test, dim = c(91,109,91))
+  Statmap = array(data = resO$Test, dim = img_dims)
   Statmap[!mask]=0
   rm(res)
   rm(scores)
@@ -129,10 +148,12 @@ pARIbrain <- function(copes, thr=NULL, mask=NULL, alpha=.05, clusters = NULL,
   
   #As first, we compute the optimal lambda
 
-  lambda <- lambdaOpt(pvalues = pvalues, family = family, alpha = alpha, delta = delta, step.down = step.down, max.step = max.step) 
+  lambda <- lambdaOpt(pvalues = pvalues, family = family, alpha = alpha, 
+                      delta = delta, step.down = step.down, max.step = max.step) 
   if(lambda == 0){lambda <- 0.05}
   #and critical vector
-  cvOpt = criticalVector(pvalues = pvalues, family = family, alpha = alpha, lambda= lambda, delta = delta)
+  cvOpt = criticalVector(pvalues = pvalues, family = family, alpha = alpha, 
+                         lambda= lambda, delta = delta)
  
   # define number of clusters
   clstr_id=sort(unique(as.vector(clusters[mask])),decreasing = TRUE)
