@@ -39,6 +39,7 @@ arma::mat permT(arma::mat X, double B, arma::vec label) {
     Tb22 = pow(M2,2); //E(X)^2
     Tb2 =  (Tb02-Tb22)*(n2/(n2-1)); //sample var
     pV = Tb1/n1 + Tb2/n2;
+    
     T.col(bb) = (M1 - M2)/sqrt(pV);
   }
   return (T);
@@ -51,6 +52,6 @@ arma::mat permT(arma::mat X, double B, arma::vec label) {
 #X = golub
 #B = 100
 #label = factor(golub.cl)
-#Test<- permTest(X , B, label)
+#Test<- permT(X , B, label)
 #str(Test)
 */
